<?php

namespace App\Http\Controllers\Admin;

use App\Classes\Reply;
use Illuminate\Http\Request;
use App\Http\Controllers\AdminBaseController;
use App\Http\Requests\Admin\LeaveApplication\CreateRequest;
use App\Http\Requests\Admin\NoticeBoard\UpdateRequest;
use App\Models\Policy;
use Illuminate\Support\Facades\View;
use Yajra\DataTables\Facades\DataTables;

class PolicyController extends AdminBaseController
{
    public function __construct() 
    {
        parent::__construct();
        $this->pageTitle = 'Policy';
        $this->policyOpen = 'active open';
        $this->policyActive = 'active';
    }

    /**
     * @return \Illuminate\Contracts\View\View
     */
    public function index()
    {
        $this->policy = Policy::orderBy('created_at', 'DESC')->get();
        return View::make('admin.policy.index', $this->data);
    }

    /**
     * @return \Illuminate\Contracts\View\View
     */
    public function create()
    {
        return View::make('admin.policy.create', $this->data);
    }

    public function store(Request $request)
    {
        
        if ($request->hasFile('document')) {
            $attach = $request->file('document');
            $name = time().'.'.$attach->getClientOriginalExtension();
            $destinationPath = public_path('/Policy/');
            $attach->move($destinationPath, $name);
            $document  = $name;
        }

        Policy::create([
            'company'           => $request->company,
            'title'             => $request->title,
        ]);

        return Reply::redirect(route('admin.policy.index'), 'Policy created successfully');

    }

    /**
     * @return mixed
     * @throws \Exception
     */
    public function ajax_policy()
    {
        $result = Policy::select('id', 'title', 'company','document', 'created_at')
            ->orderBy('created_at', 'desc');

        return DataTables::of($result)
            ->editColumn('created_at', function ($row) {
                return date('d-M-Y', strtotime($row->created_at));
            })
            ->make(false);

    }

    /**
     * @param $id
     * @return \Illuminate\Contracts\View\View
     */
    public function edit($id)
    {
        $this->policy = Policy::find($id);

        return View::make('admin.policy.edit', $this->data);
    }

    /**
     * @param $id
     * @return \Illuminate\Contracts\View\View
     */
    public function show($id)
    {
        $this->notice = Policy::find($id);

        return View::make('front.policy-detail', $this->data);
    }

    /**
     * @param UpdateRequest $request
     * @param $id
     * @return array
     */
    public function update(Request $request, $id)
    {
        $policy = Policy::findOrFail($id);
        
        if ($request->hasFile('document')) { 
            $icon = $request->file('document');
            $root = time().'.'.$icon->getClientOriginalExtension();
            $destinationPath = public_path('/Policy/');
            $icon->move($destinationPath, $root);
            $policy->document  = $root;
        }

            $policy->title      = $request->title;
            $policy->company    = $request->company;
        
            
            $policy->update();

        return Reply::redirect(route('admin.policy.index'), 'Policy updated successfully');
    }

    /**
     * @param $id
     * @return array
     */
    public function destroy($id)
    {
        Policy::destroy($id);
        return Reply::success('Deleted successfully');
    }
}
